@@ -1,5 +1,5 @@
-/* Copyright (C) 2004 Thorsten Kukuk
-   Author: Thorsten Kukuk <kukuk@suse.de>
+/* Copyright (C) 2004, 2005 Thorsten Kukuk
+   Author: Thorsten Kukuk <kukuk@thkukuk.de>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License version 2 as
@@ -21,12 +21,22 @@
 
 extern void open_sec_log (const char *program);
 
-extern void (*sec_log_fnc) (const char *program, unsigned int id, ...);
+struct logfunc_t {
+  void (*sec_log_fnc) (const char *program, unsigned int id, ...);
+  void (*open_sec_log_fnc) (const char *arguments);
+  struct logfunc_t *next;
+};
 
-#define sec_log(program, id, args...)     \
-  do {                                    \
-    if (sec_log_fnc)                      \
-      sec_log_fnc (program, id, ##args);  \
+extern struct logfunc_t *logfunc_list;
+
+#define sec_log(program, id, args...)			\
+  do {							\
+    struct logfunc_t *listptr = logfunc_list;		\
+    while (listptr)					\
+      {							\
+	listptr->sec_log_fnc (program, id, ##args);	\
+	listptr = listptr->next;			\
+      }							\
   } while (0);
 
 #define MSG_PATH_ARG_DENIED 1 /* caller uid */
