@@ -1,5 +1,5 @@
-/* Copyright (C) 2002, 2003, 2004 Thorsten Kukuk
-   Author: Thorsten Kukuk <kukuk@suse.de>
+/* Copyright (C) 2002, 2003, 2004, 2005 Thorsten Kukuk
+   Author: Thorsten Kukuk <kukuk@thkukuk.de>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License version 2 as
@@ -85,20 +85,20 @@ getnismaster (void)
 
   if ((err = yp_master (domainname, "passwd.byname", &master)) != 0)
     {
-      fprintf (stderr, _("can't find the master ypserver: %s\n"),
+      fprintf (stderr, _("Can't find the NIS master server: %s\n"),
 	       yperr_string (err));
       return NULL;
     }
   port = getrpcport (master, YPPASSWDPROG, YPPASSWDPROC_UPDATE, IPPROTO_UDP);
   if (port == 0)
     {
-      fprintf (stderr, _("yppasswdd not running on NIS master %s\n"), master);
+      fprintf (stderr, _("rpc.yppasswdd not running on NIS master %s.\n"), master);
       return NULL;
     }
   if (port >= IPPORT_RESERVED)
     {
       fprintf (stderr,
-	       _("yppasswd daemon running on illegal port on NIS master %s.\n"),
+	       _("rpc.yppasswdd running on illegal port on NIS master %s.\n"),
 	       master);
       return NULL;
     }
