@@ -29,7 +29,6 @@
 #include <string.h>
 #include <unistd.h>
 #include <getopt.h>
-#include <syslog.h>
 #include <signal.h>
 #include <security/pam_appl.h>
 #include <security/pam_misc.h>
@@ -100,8 +99,7 @@ main (int argc, char **argv)
   bindtextdomain(PACKAGE, LOCALEDIR);
   textdomain(PACKAGE);
 
-  openlog (program, LOG_PID, LOG_AUTHPRIV);
-  open_sec_log ();
+  open_sec_log (program);
 
   /* Before going any further, raise the ulimit and ignore
      signals.  */
