@@ -1,4 +1,4 @@
-/* Copyright (C) 2004 Thorsten Kukuk
+/* Copyright (C) 2004, 2005 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    This program is free software; you can redistribute it and/or modify
@@ -305,7 +305,10 @@ loop_over_group_file (int quiet)
         n = 0;
 #endif /* HAVE_GETLINE / HAVE_GETDELIM */
 
-      cp = buf;
+      if (buf)
+	cp = strdup (buf);
+      else
+	cp = strdup (buf);
 
       if (n < 1)
 	{
@@ -316,6 +319,7 @@ loop_over_group_file (int quiet)
 	  printf (_("Delete empty line? "));
 	  if (answer_yes ())
 	    {
+	      free (cp);
 	      modified = 1;
 	      continue;
 	    }
@@ -338,6 +342,7 @@ loop_over_group_file (int quiet)
 	  printf (_("Delete line `%s'? "), cp);
 	  if (answer_yes ())
 	    {
+	      free (cp);
 	      modified = 1;
 	      continue;
 	    }
@@ -345,7 +350,6 @@ loop_over_group_file (int quiet)
 	    goto write_gr;
 	}
 
-      cp = strdup (buf);
       /* Parse string in strict mode and report error.  */
       {
 	int status;
@@ -437,7 +441,6 @@ loop_over_group_file (int quiet)
     write_gr:
       fprintf (output, "%s\n", cp);
       free (cp);
-      buf[0] = '\0';
     }
 
 
