@@ -221,7 +221,7 @@ main (int argc, char *argv[])
 	     to create it. Else report an error and abort.  */
 	  if (errno == ENOENT)
 	    {
-	      fprintf (stderr, _("%s: Now gshadow file found.\n"),
+	      fprintf (stderr, _("%s: No gshadow file found.\n"),
 		       program);
 	      return E_FAILURE;
 	    }
