@@ -143,7 +143,7 @@ print_help (const char *program)
   print_usage (stdout, program);
   fprintf (stdout, _("%s - change password information\n\n"), program);
 
-  fputs (_("  -f             Change the finger (gecos) information\n"),
+  fputs (_("  -f             Change the finger (GECOS) information\n"),
          stdout);
   fputs (_("  -h             Change the home directory\n"), stdout);
   fputs (_("  -s             Change the login shell\n"), stdout);
