@@ -1,4 +1,4 @@
-/* Copyright (C) 2004 Thorsten Kukuk
+/* Copyright (C) 2004, 2005 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    This program is free software; you can redistribute it and/or modify
@@ -312,7 +312,10 @@ loop_over_passwd_file (int quiet)
         n = 0;
 #endif /* HAVE_GETLINE / HAVE_GETDELIM */
 
-      cp = buf;
+      if (buf)
+	cp = strdup (buf);
+      else
+	cp = strdup ("");
 
       if (n < 1)
 	{
@@ -323,6 +326,7 @@ loop_over_passwd_file (int quiet)
 	  printf (_("Delete empty line? "));
 	  if (answer_yes ())
 	    {
+	      free (cp);
 	      modified = 1;
 	      continue;
 	    }
@@ -331,8 +335,8 @@ loop_over_passwd_file (int quiet)
 	}
 
       /* Remove trailing '\n'.  */
-      if (buf[strlen (buf) - 1] == '\n')
-	buf[strlen (buf) - 1] = '\0';
+      if (cp[strlen (cp) - 1] == '\n')
+	cp[strlen (cp) - 1] = '\0';
 
       if (*cp == '+' || *cp == '-')
 	goto write_pw;
@@ -346,13 +350,13 @@ loop_over_passwd_file (int quiet)
 	  if (answer_yes ())
 	    {
 	      modified = 1;
+	      free (cp);
 	      continue;
 	    }
 	  else
 	    goto write_pw;
 	}
 
-      cp = strdup (buf);
       /* Parse string in strict mode and report error.  */
       if (parse_pwent (buf, &res, 1) != 1)
 	{
@@ -431,7 +435,6 @@ loop_over_passwd_file (int quiet)
     write_pw:
       fprintf (output, "%s\n", cp);
       free (cp);
-      buf[0] = '\0';
     }
 
 
@@ -551,7 +554,10 @@ loop_over_shadow_file (int quiet)
         n = 0;
 #endif /* HAVE_GETLINE / HAVE_GETDELIM */
 
-      cp = buf;
+      if (buf)
+	cp = strdup (buf);
+      else
+	cp = strdup ("");
 
       if (n < 1)
 	{
@@ -563,6 +569,7 @@ loop_over_shadow_file (int quiet)
 	  if (answer_yes ())
 	    {
 	      modified = 1;
+	      free (cp);
 	      continue;
 	    }
 	  else
@@ -570,8 +577,8 @@ loop_over_shadow_file (int quiet)
 	}
 
       /* Remove trailing '\n'.  */
-      if (buf[strlen (buf) - 1] == '\n')
-	buf[strlen (buf) - 1] = '\0';
+      if (cp[strlen (cp) - 1] == '\n')
+	cp[strlen (cp) - 1] = '\0';
 
       if (*cp == '+' || *cp == '-')
 	goto write_pw;
@@ -591,7 +598,6 @@ loop_over_shadow_file (int quiet)
 	    goto write_pw;
 	}
 
-      cp = strdup (buf);
       /* Parse string in strict mode and report error.  */
       if (parse_spent (buf, &res, 1) != 1)
 	{
@@ -668,7 +674,6 @@ loop_over_shadow_file (int quiet)
     write_pw:
       fprintf (output, "%s\n", cp);
       free (cp);
-      buf[0] = '\0';
     }
 
 
