@@ -169,7 +169,7 @@ main (int argc, char *argv[])
 	     to create it. Else report an error and abort.  */
 	  if (errno == ENOENT)
 	    {
-	      fprintf (stderr, _("%s: Now shadow file found.\n"),
+	      fprintf (stderr, _("%s: No shadow file found.\n"),
 		       program);
 	      return E_FAILURE;
 	    }
