@@ -1,4 +1,4 @@
-/* Copyright (C) 2002, 2003, 2004 Thorsten Kukuk
+/* Copyright (C) 2002, 2003, 2004, 2005 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    This program is free software; you can redistribute it and/or modify
@@ -702,7 +702,7 @@ print_x509_certificate_info (HANDLE gnutls_session session)
   unsigned int algo, bits;
   time_t expiration_time, activation_time;
   const gnutls_datum *cert_list;
-  int cert_list_size = 0;
+  unsigned int cert_list_size = 0;
   gnutls_x509_crt cert;
 
   /* This function only works for X.509 certificates.
