@@ -1,4 +1,4 @@
-/* Copyright (C) 2002, 2003, 2004 Thorsten Kukuk
+/* Copyright (C) 2002, 2003, 2004, 2005 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    This program is free software; you can redistribute it and/or modify
@@ -845,7 +845,11 @@ initialize_gnutls_session (const char *certificate, const char *privatekey)
 /* This is the main loop.  It can be replicated in different threads but the
    `poll' call makes sure only one thread handles an incoming connection.  */
 static void
+#ifdef USE_GNUTLS
 server_run (const char *certificate, const char *privatekey)
+#else
+server_run (void)
+#endif
 {
   int i;
 
@@ -1415,7 +1419,11 @@ main (int argc, char **argv)
 #endif
 
   /* Handle incoming requests.  */
+#ifdef USE_GNUTLS
   server_run (certificate, privatekey);
+#else
+  server_run ();
+#endif
 
   return E_SUCCESS;
 }
