@@ -67,7 +67,7 @@ print_help (const char *program)
   print_usage (stdout, program);
   fprintf (stdout, _("%s - modify a user account\n\n"), program);
 
-  fputs (_("  -c comment     Set the gecos field for the new account\n"),
+  fputs (_("  -c comment     Set the GECOS field for the new account\n"),
 	 stdout);
   fputs (_
 	 ("  -D binddn      Use dn \"binddn\" to bind to the LDAP directory\n"),
@@ -154,7 +154,7 @@ convert_grpopt_to_name (const char *arg, char **grouplist, gid_t *groupid,
 
       if (strtoid (arg, &gid) == -1)	/* invalid number */
 	{
-	  fprintf (stderr, _("%s: invalid numeric argument `%s'.\n"),
+	  fprintf (stderr, _("%s: Invalid numeric argument `%s'.\n"),
 		   program, arg);
 	  return E_BAD_ARG;
 	}
@@ -171,7 +171,7 @@ convert_grpopt_to_name (const char *arg, char **grouplist, gid_t *groupid,
 	    }
 	  else
 	    {
-	      fprintf (stderr, _("%s: unknown group `%u'.\n"), program, gid);
+	      fprintf (stderr, _("%s: Unknown group `%u'.\n"), program, gid);
 	      return E_BAD_ARG;
 	    }
 	}
@@ -190,7 +190,7 @@ convert_grpopt_to_name (const char *arg, char **grouplist, gid_t *groupid,
 	    }
 	  else
 	    {
-	      fprintf (stderr, _("%s: unknown group `%s'.\n"), program,
+	      fprintf (stderr, _("%s: Unknown group `%s'.\n"), program,
 		       utf8_to_locale (arg));
 	      return E_BAD_ARG;
 	    }
@@ -787,7 +787,7 @@ main (int argc, char **argv)
 	case 'c':
 	  if (strcspn (optarg, ":\n") != strlen (optarg))
 	    {
-	      fprintf (stderr, _("%s: invalid comment `%s'.\n"),
+	      fprintf (stderr, _("%s: Invalid comment `%s'.\n"),
 		       program, optarg);
 	      return E_BAD_ARG;
 	    }
@@ -801,7 +801,7 @@ main (int argc, char **argv)
 	case 'd':
 	  if (check_home (optarg) == -1)
 	    {
-	      fprintf (stderr, _("%s: invalid home directory `%s'.\n"),
+	      fprintf (stderr, _("%s: Invalid home directory `%s'.\n"),
 		       program, optarg);
 	      return E_BAD_ARG;
 	    }
@@ -841,7 +841,7 @@ main (int argc, char **argv)
 	    inactive = strtol (optarg, &cp, 10);
 	    if (*cp != '\0')	/* invalid number */
 	      {
-		fprintf (stderr, _("%s: invalid numeric argument `%s'.\n"),
+		fprintf (stderr, _("%s: Invalid numeric argument `%s'.\n"),
 			 program, optarg);
 		return E_BAD_ARG;
 	      }
@@ -913,7 +913,7 @@ main (int argc, char **argv)
 	  if (strcspn (optarg, ":\n") != strlen (optarg))
 	    {
 	      fprintf (stderr,
-		       _("%s: invalid characters in password `%s'.\n"),
+		       _("%s: Invalid characters in password `%s'.\n"),
 		       program, optarg);
 	      return E_BAD_ARG;
 	    }
@@ -923,7 +923,7 @@ main (int argc, char **argv)
 	  if (strcspn (optarg, ",=\":*\n") != strlen (optarg) ||
 	      *optarg != '/')
 	    {
-	      fprintf (stderr, _("%s: invalid shell `%s'.\n"),
+	      fprintf (stderr, _("%s: Invalid shell `%s'.\n"),
 		       program, optarg);
 	      return E_BAD_ARG;
 	    }
@@ -936,7 +936,7 @@ main (int argc, char **argv)
 	    new_uid = strtoul (optarg, &cp, 10);
 	    if (*cp != '\0')	/* invalid number */
 	      {
-		fprintf (stderr, _("%s: invalid numeric argument `%s'.\n"),
+		fprintf (stderr, _("%s: Invalid numeric argument `%s'.\n"),
 			 program, optarg);
 		return E_BAD_ARG;
 	      }
